<h1 align="center">
navigate-mmcore-plugin
	
<h2 align="center">
	A plugin for interfacing with MMCore devices.
</h2>
</h1>

Micro-Manager is a popular open-source microscopy software that provides a wide range of 
device support. The `navigate-mmcore-plugin` is a plugin for the `navigate` light-sheet 
microscope control software that enables users to interface with Micro-Manager devices.
Currently, only stages and shutters are supported. Future releases will enable operation of
cameras and other devices.

### Documentation

Please refer to and contribute to the documentation, which can be found on GitHub Pages: [https://thedeanlab.github.io/navigate-mmcore-plugin/](https://thedeanlab.github.io/navigate-mmcore-plugin/).

### Support

For support or questions about using this template, please open an issue in the GitHub repository.

